require 'studio_game/game'
require 'studio_game/spec_helper'

module StudioGame
  describe Game do
  
    before do
      @game = Game.new("Curmudgeons")
    
      @initial_health = 100
      @player = Philosopher.new("camus", @initial_health)
    
      @game.add_player(@player)
      $stdout = StringIO.new
    
      @rounds = 3
    end
  
    it "w00ts a player if a high number is rolled" do
      Die.any_instance.stub(:roll).and_return(5)
    
      @game.play(@rounds)
    
      @player.health.should == @initial_health + (15 * @rounds)
    end
  
    it "skips a player if a medium number is rolled" do
      Die.any_instance.stub(:roll).and_return(3)
    
      @game.play(@rounds)
    
      @player.health.should == @initial_health
    end
  
    it "blams a player if a low number is rolled" do
      Die.any_instance.stub(:roll).and_return(1)
    
      @game.play(@rounds)
    
      @player.health.should == @initial_health - (20 * @rounds)
    end
  
    it "assigns an epiphany for points during a player's turn" do
      game = Game.new("the_great_philosophers")
      player = Philosopher.new("camus")

      game.add_player(player)

      game.play(1)

      player.points.should_not be_zero

      # or use alternate expectation syntax:
      # expect(player.points).not_to be_zero
    end
  
    it "computes total points as the sum of all player points" do
      game = Game.new("the_great_philosophers")

      player1 = Philosopher.new("camus")
      player2 = Philosopher.new("sartre")

      game.add_player(player1)
      game.add_player(player2)

      player1.discovered_epiphanies(Epiphany.new(:an_indubitable_truth, 50))
      player1.discovered_epiphanies(Epiphany.new(:an_indubitable_truth, 50))
      player2.discovered_epiphanies(Epiphany.new(:the_problem_of_induction, 200))

      game.total_points.should == 300
    end
  end
end